@@ -2,9 +2,9 @@
  *
  *  $RCSfile: frmpage.cxx,v $
  *
- *  $Revision: 1.36.160.1 $
+ *  $Revision: 1.36.160.2 $
  *
- *  last change: $Author: hr $ $Date: 2004/01/09 14:33:24 $
+ *  last change: $Author: vg $ $Date: 2004/08/27 09:31:28 $
  *
  *  The Contents of this file are made available subject to the terms of
  *  either of the following licenses
@@ -551,7 +551,7 @@ void lcl_InsertVectors(ListBox& rBox,
     const ::std::vector< String >& rPrev, const ::std::vector< String >& rThis,
     const ::std::vector< String >& rNext, const ::std::vector< String >& rRemain)
 {
-    ::std::vector< const String >::iterator aIt;
+    ::std::vector< String >::const_iterator aIt;
     USHORT nEntry = 0;
     for(aIt = rPrev.begin(); aIt != rPrev.end(); aIt++)
         nEntry = rBox.InsertEntry(*aIt);
